# [0.2.8](https://github.com/seriaati/akasha-py/compare/v0.2.7..v0.2.8) - 2024-11-24

## Bug Fixes

- Fix AttributeError on UserCalc.calculations - ([58e9620](https://github.com/seriaati/akasha-py/commit/58e9620731c60d98e4f32f47e1b4e5f54f616e43))

## Continuous Integrations

- Simplify ruff lint workflow - ([69508f8](https://github.com/seriaati/akasha-py/commit/69508f86d10e54b4e21b385b07c0d98823fb5a30))

## Improvements

- Allow getting leaderboard for multiple uids - ([0e6d639](https://github.com/seriaati/akasha-py/commit/0e6d6393a455c3f9ccbfa6dae7e0ca324c0bbdce))

## Miscellaneous Chores

- **(ruff)** Remove deprecated lint rules - ([1c5a8cd](https://github.com/seriaati/akasha-py/commit/1c5a8cda8bdf697dec99fe714c0452ddf90793ab))

